import lennpy as le

import argparse

parser = argparse.ArgumentParser(description='Lennies in the command line. Need be said more?')

parser.add_argument('emotion', default='basic', nargs='?', type=str, help='the emotion of the lenny')
parser.add_argument('-r', dest='randomized', action='store_const', default=False, const=True, help='randomized lenny face generation')
parser.add_argument('-e', '--emotions', action='store_const', default=False, const=True, help='list all available emotions')

args = parser.parse_args()

def main():
    if args.emotions:
        print("\n".join(le.emotions()))
    else:
        print(le.get(args.emotion, args.randomized))



#!/usr/bin/env python
# -*- coding: UTF-8 -*-

lennys = {}

def get_lennys_from_emotion(emotion):
    return lennys[emotion]

def generate_faces(mouths, eyes, ears):
    output_lennys = []
    for mouth in mouths:
        for eye in eyes:
            if isinstance(eye, tuple):
                left_eye, right_eye = eye
            else:
                left_eye = right_eye = eye
            for ear in ears:
                if isinstance(ear, tuple):
                    left_ear, right_ear = ear
                else:
                    left_ear = right_ear = ear
                
                lenny = left_ear + left_eye + mouth + right_eye + right_ear
                if not lenny in output_lennys:
                    output_lennys.append(lenny)
    return output_lennys


lennys['basic'] = ['( ͡° ͜ʖ ͡°)'] + generate_faces(
    mouths = [
        ' ͜ʖ',
        ' ل͜',
        '╭͜ʖ╮'
    ],
    eyes = [
        ' ͡°',
        ' °',
        ' ᴗ',
        ' ͡☉',
        ' ͡◉',
        '๏',
        'ᵔ',
        (' ͠°', '°')
    ],
    ears = [
        ('(', ')'),
        ('ʕ', 'ʔ')
    ]
)


lennys['table_flip'] = ['(╯°□°)╯︵ ┻━┻'] + generate_faces(
    mouths = [
        ' ▽ ',
        ' _ ',
        '□',
        ' ͜ʖ',
        ' ل͜',
        'Д'
    ],
    eyes = [
        ' ͡°',
        ' °',
        '๏',
        'ᵔ'
    ],
    ears = [
        ('(╯', ')╯︵/(.□ . \)'),
        ('(ノ', ')ノ彡┻━┻'),
        ('┻━┻ ︵﻿ ¯\_(', ')_/¯ ︵ ┻━┻'),
        ('(╯', ')╯︵ ┻━┻')
    ]
)


lennys['happy'] = ['☜(⌒▽⌒)☞'] + generate_faces(
    mouths = [
        '▽',
        'ヮ',
        '‿',
        'ᗜ'
    ],
    eyes = [
        ' ͡^',
        '⌒',
        '∩',
        '^',
        ('´', '`')
    ],
    ears = [
        ('(', ')'),
        ('☜(', ')☞'),
        ('(✿', ')'),
        ('(づ ', ' )づ'),
        ('\( ', ' )/')
    ]
)


import setuptools

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="lennpy",
    version="0.0.8",
    author="Stefan Zdravkovic",
    author_email="stefan.zdra@gmail.com",
    description="Generate Lenny Faces",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=['lenny', 'memes'],
    url="https://github.com/Histefanhere/lennpy",
    packages=setuptools.find_packages(),
    license='GNU GPLv3',
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3",
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent"
    ],
    entry_points = {
        'console_scripts': ['lennpy=lennpy.command_line:main']
    }
)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-

import random
import sys

from . import faces
lennys = faces.lennys

# This class lets us make the easiest interface possible for the package
class Emotion:
    def __init__(self, name):
        self.name = name

    def __repr__(self):
        """Called when an attribute of the module is gotten
        E.G. `lennpy.basic` will return the first basic lenny via this method."""
        return lennys[self.name][0]

    def __call__(self, *args):
        """Called when an attribute of the module is called
        E.G. `lenny.basic()` will return a random basic lenny via this method."""
        return random.choice(lennys[self.name])

# And now create all the "fake" module attributes
module = sys.modules[__name__]
for emotion_name in lennys.keys():
    setattr(module, emotion_name, Emotion(emotion_name))


# Programmatic interface for getting the available emotions and a specific lenny via function calls
# A.K.A. lame and so 2015.
class InvalidEmotion(Exception):
    def __init__(self, emotion):
        super().__init__(f"{emotion} is not a valid emotion")

def emotions():
    return list(lennys.keys())

def get(emotion, randomized=False):
    if emotion not in lennys.keys():
        raise InvalidEmotion(emotion)
    if randomized:
        return random.choice(lennys[emotion])
    else:
        return lennys[emotion][0]

